@@ -58,54 +58,6 @@ idS                             = id
                                     }
 
 -- ------------------------------------------------------------
--- TODO: delete theses
-{-
-subS                    :: Selector b c -> Selector a b -> Selector a c
-subS = (.)
-
-pairS                   :: Selector s a -> Selector s b -> Selector s (a, b)
-pairS = (.&&&.)
-
-chgS                    :: Selector s a -> (a -> a) -> (s -> s)
-chgS = update
-
-putS                    :: Selector s a -> a -> (s -> s)
-putS = setS
-
--}
--- ------------------------------------------------------------
-{-
-type Selector s a       = (s -> a, a -> s -> s)
-
-subS                    :: Selector b c -> Selector a b -> Selector a c
-subS (g2, s2) (g1, s1)  = ( g2 . g1
-                          , s1s2
-                          )
-                          where
-                          s1s2 x s = s'
-                              where
-                              x1  = g1 s
-                              x1' = s2 x x1
-                              s'  = s1 x1' s
-
-pairS                   :: Selector s a -> Selector s b -> Selector s (a, b)
-pairS (g1, s1) (g2, s2) = ( g1 &&& g2
-                          , \ (x, y) -> s2 y . s1 x
-                          )
-
-chgS                    :: Selector s a -> (a -> a) -> (s -> s)
-chgS (g, s) f x         = s (f (g x)) x
-
-getS                    :: Selector s a -> s -> a
-getS                    = fst                           -- getS (g, _s) x = g x
-
-putS                    :: Selector s a -> a -> (s -> s)
-putS s v                = chgS s (const v)
-
-idS                     :: Selector s s
-idS                     = (id, const)
--}
--- ------------------------------------------------------------
 
 -- | Selectors for pairs and 3-tuples: comp1, comp2, comp3,
 -- this can be extended to n-tuples
